@@ -16,29 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.accessapproval_v1.services.access_approval import pagers
-from google.cloud.accessapproval_v1.types import accessapproval
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import AccessApprovalTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.accessapproval_v1.services.access_approval import pagers
+from google.cloud.accessapproval_v1.types import accessapproval
+
+from .transports.base import DEFAULT_CLIENT_INFO, AccessApprovalTransport
 from .transports.grpc import AccessApprovalGrpcTransport
 from .transports.grpc_asyncio import AccessApprovalGrpcAsyncIOTransport
 
@@ -57,7 +59,10 @@ class AccessApprovalClientMeta(type):
     _transport_registry["grpc"] = AccessApprovalGrpcTransport
     _transport_registry["grpc_asyncio"] = AccessApprovalGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[AccessApprovalTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[AccessApprovalTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -197,9 +202,28 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         return self._transport
 
     @staticmethod
-    def access_approval_settings_path(project: str,) -> str:
+    def access_approval_service_account_path(
+        project: str,
+    ) -> str:
+        """Returns a fully-qualified access_approval_service_account string."""
+        return "projects/{project}/serviceAccount".format(
+            project=project,
+        )
+
+    @staticmethod
+    def parse_access_approval_service_account_path(path: str) -> Dict[str, str]:
+        """Parses a access_approval_service_account path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/serviceAccount$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def access_approval_settings_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified access_approval_settings string."""
-        return "projects/{project}/accessApprovalSettings".format(project=project,)
+        return "projects/{project}/accessApprovalSettings".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_access_approval_settings_path(path: str) -> Dict[str, str]:
@@ -208,10 +232,14 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def approval_request_path(project: str, approval_request: str,) -> str:
+    def approval_request_path(
+        project: str,
+        approval_request: str,
+    ) -> str:
         """Returns a fully-qualified approval_request string."""
         return "projects/{project}/approvalRequests/{approval_request}".format(
-            project=project, approval_request=approval_request,
+            project=project,
+            approval_request=approval_request,
         )
 
     @staticmethod
@@ -224,7 +252,9 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -237,9 +267,13 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -248,9 +282,13 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -259,9 +297,13 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -270,10 +312,14 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -461,7 +507,6 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         filtered by state (pending, active, dismissed). The
         order is reverse chronological.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
@@ -540,12 +585,20 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListApprovalRequestsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -563,7 +616,6 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         r"""Gets an approval request. Returns NOT_FOUND if the request does
         not exist.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
@@ -636,7 +688,12 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -655,7 +712,6 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         FAILED_PRECONDITION if the request exists but is not in a
         pending state.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
@@ -709,7 +765,12 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -733,7 +794,6 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         Returns FAILED_PRECONDITION if the request exists but is not in
         a pending state.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
@@ -787,7 +847,95 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def invalidate_approval_request(
+        self,
+        request: Union[accessapproval.InvalidateApprovalRequestMessage, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> accessapproval.ApprovalRequest:
+        r"""Invalidates an existing ApprovalRequest. Returns the updated
+        ApprovalRequest.
+
+        NOTE: This does not deny access to the resource if another
+        request has been made and approved. It only invalidates a single
+        approval.
+
+        Returns FAILED_PRECONDITION if the request exists but is not in
+        an approved state.
+
+        .. code-block:: python
+
+            from google.cloud import accessapproval_v1
+
+            def sample_invalidate_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.InvalidateApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = client.invalidate_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.accessapproval_v1.types.InvalidateApprovalRequestMessage, dict]):
+                The request object. Request to invalidate an existing
+                approval.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
+                A request for the customer to approve
+                access to a resource.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a accessapproval.InvalidateApprovalRequestMessage.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, accessapproval.InvalidateApprovalRequestMessage):
+            request = accessapproval.InvalidateApprovalRequestMessage(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[
+            self._transport.invalidate_approval_request
+        ]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -804,7 +952,6 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         r"""Gets the settings associated with a project, folder,
         or organization.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
@@ -882,7 +1029,12 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -901,7 +1053,6 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         organization. Settings to update are determined by the value of
         field_mask.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
@@ -996,7 +1147,12 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1019,7 +1175,6 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         still be enabled at this level as the settings are
         inherited.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
@@ -1087,9 +1242,116 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
+    def get_access_approval_service_account(
+        self,
+        request: Union[
+            accessapproval.GetAccessApprovalServiceAccountMessage, dict
+        ] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> accessapproval.AccessApprovalServiceAccount:
+        r"""Retrieves the service account that is used by Access
+        Approval to access KMS keys for signing approved
+        approval requests.
+
+        .. code-block:: python
+
+            from google.cloud import accessapproval_v1
+
+            def sample_get_access_approval_service_account():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.GetAccessApprovalServiceAccountMessage(
+                )
+
+                # Make the request
+                response = client.get_access_approval_service_account(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.accessapproval_v1.types.GetAccessApprovalServiceAccountMessage, dict]):
+                The request object. Request to get an Access Approval
+                service account.
+            name (str):
+                Name of the
+                AccessApprovalServiceAccount to
+                retrieve.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.accessapproval_v1.types.AccessApprovalServiceAccount:
+                Access Approval service account
+                related to a
+                project/folder/organization.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a accessapproval.GetAccessApprovalServiceAccountMessage.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(
+            request, accessapproval.GetAccessApprovalServiceAccountMessage
+        ):
+            request = accessapproval.GetAccessApprovalServiceAccountMessage(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[
+            self._transport.get_access_approval_service_account
+        ]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def __enter__(self):
         return self
 
