@@ -15,18 +15,18 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+import pkg_resources
 
 from google.cloud.accessapproval_v1.types import accessapproval
-from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -81,6 +81,7 @@ class AccessApprovalTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -159,6 +160,11 @@ class AccessApprovalTransport(abc.ABC):
                 default_timeout=600.0,
                 client_info=client_info,
             ),
+            self.invalidate_approval_request: gapic_v1.method.wrap_method(
+                self.invalidate_approval_request,
+                default_timeout=600.0,
+                client_info=client_info,
+            ),
             self.get_access_approval_settings: gapic_v1.method.wrap_method(
                 self.get_access_approval_settings,
                 default_retry=retries.Retry(
@@ -183,14 +189,19 @@ class AccessApprovalTransport(abc.ABC):
                 default_timeout=600.0,
                 client_info=client_info,
             ),
+            self.get_access_approval_service_account: gapic_v1.method.wrap_method(
+                self.get_access_approval_service_account,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -239,6 +250,17 @@ class AccessApprovalTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def invalidate_approval_request(
+        self,
+    ) -> Callable[
+        [accessapproval.InvalidateApprovalRequestMessage],
+        Union[
+            accessapproval.ApprovalRequest, Awaitable[accessapproval.ApprovalRequest]
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def get_access_approval_settings(
         self,
@@ -272,5 +294,21 @@ class AccessApprovalTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def get_access_approval_service_account(
+        self,
+    ) -> Callable[
+        [accessapproval.GetAccessApprovalServiceAccountMessage],
+        Union[
+            accessapproval.AccessApprovalServiceAccount,
+            Awaitable[accessapproval.AccessApprovalServiceAccount],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("AccessApprovalTransport",)
