@@ -14,6 +14,7 @@
 # limitations under the License.
 #
 from .accessapproval import (
+    AccessApprovalServiceAccount,
     AccessApprovalSettings,
     AccessLocations,
     AccessReason,
@@ -24,16 +25,20 @@ from .accessapproval import (
     DismissApprovalRequestMessage,
     DismissDecision,
     EnrolledService,
+    EnrollmentLevel,
+    GetAccessApprovalServiceAccountMessage,
     GetAccessApprovalSettingsMessage,
     GetApprovalRequestMessage,
+    InvalidateApprovalRequestMessage,
     ListApprovalRequestsMessage,
     ListApprovalRequestsResponse,
     ResourceProperties,
+    SignatureInfo,
     UpdateAccessApprovalSettingsMessage,
-    EnrollmentLevel,
 )
 
 __all__ = (
+    "AccessApprovalServiceAccount",
     "AccessApprovalSettings",
     "AccessLocations",
     "AccessReason",
@@ -44,11 +49,14 @@ __all__ = (
     "DismissApprovalRequestMessage",
     "DismissDecision",
     "EnrolledService",
+    "GetAccessApprovalServiceAccountMessage",
     "GetAccessApprovalSettingsMessage",
     "GetApprovalRequestMessage",
+    "InvalidateApprovalRequestMessage",
     "ListApprovalRequestsMessage",
     "ListApprovalRequestsResponse",
     "ResourceProperties",
+    "SignatureInfo",
     "UpdateAccessApprovalSettingsMessage",
     "EnrollmentLevel",
 )
